==> prestashop_1.4.0.3.zip: prestashop/modules/fianetfraud/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{fianetfraud}prestashop>fianetfraud_740e53a0ed1b643f69c4aaa8ad4ae8d2'] = 'Code transporteur invalide';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_39b34487212efb0589ecf8c774413d85'] = 'Le numéro de téléphone est obligatoire';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuration';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_99dea78007133396a7b8ed70578ac6ae'] = 'Utilisateur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b250a007769c7ffe655c74cfb8176b8c'] = 'ID Site';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_30dbd3dffa9dbd08b062436ba8dcbad7'] = 'Mode production';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_99dbbd4d0ac4c725f3b0d2ff29abaf63'] = 'Type par défaut';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_7bc873cba11f035df692c3549366c722'] = '-- Choisissez --';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_5515d101ace462b70d5b5b5e55a8bfec'] = 'Détail';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Catégorie';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_32b1e872d533aced68e8fd06117c35d9'] = 'Type';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_bb8d6a9f57dcf8f450d8c8b6107cfabb'] = 'Choix de la catégorie';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_5f001485711e47385cb84b10c888bbfd'] = 'Configuration du transporteur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_84a4ee79ed85180a743340dceb2f98d1'] = 'Détail';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_fecb07f7ab46e23e9b520a9a9af7b97b'] = 'Type de transporteur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b04ad61ad875f6e7149fdd51c2e60ce2'] = 'Choix du type de transporteur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_803d8f90719db3a605cf4af72ab2d8ee'] = 'Type de transporteur par defaut';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b41c57d638ef2d97b9231fb660dd136e'] = 'Configuration du paiement';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_417f4dcb050401b8e65f19f152bc2781'] = 'Detail du paiement';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_521e389890dc5f0b41a83fa187eb3878'] = 'Module de paiement';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_676b323eb96e2d3fa5b9afd415781b9a'] = 'Type de paiement';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_d8187ca1c7189a53c2ac6e8a7fe351d6'] = 'monsieur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_43ee1d83b74b6407b7bf4160a5b28fd7'] = 'madame';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_bf8fdb0995bc7db74f365551ffe9cf21'] = 'Monsieur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_2b8713f4b603c6b9d9e8a10b6f4447d1'] = 'Madame';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_88183b946cc5f0e8c96b2e66e1c74a7e'] = 'Inconnu';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_d13270d4831bb2a2723f0fb5b573807c'] = 'Validation Fia-Net';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_e010021939a49b7cce07f0e546c1d54f'] = 'Voir le détail';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_34f8a10ae57ac230a48fc44908bd40ad'] = 'Evaluation';

==> prestashop_1.4.0.7.zip: prestashop/modules/fianetfraud/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{fianetfraud}prestashop>fianetfraud_740e53a0ed1b643f69c4aaa8ad4ae8d2'] = 'Code transporteur invalide';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_39b34487212efb0589ecf8c774413d85'] = 'Le client devra obligatoirement renseigner son numéro de téléphone lors de la création de son compte.';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuration';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_99dea78007133396a7b8ed70578ac6ae'] = 'Utilisateur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b250a007769c7ffe655c74cfb8176b8c'] = 'ID Site';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_30dbd3dffa9dbd08b062436ba8dcbad7'] = 'Mode production';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_99dbbd4d0ac4c725f3b0d2ff29abaf63'] = 'Type par défaut';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_7bc873cba11f035df692c3549366c722'] = '-- Choisissez --';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_5515d101ace462b70d5b5b5e55a8bfec'] = 'Détail';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_3adbdb3ac060038aa0e6e6c138ef9873'] = 'Catégorie';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_32b1e872d533aced68e8fd06117c35d9'] = 'Type';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_bb8d6a9f57dcf8f450d8c8b6107cfabb'] = 'Choix de la catégorie';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_5f001485711e47385cb84b10c888bbfd'] = 'Configuration du transporteur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_84a4ee79ed85180a743340dceb2f98d1'] = 'Détail';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_fecb07f7ab46e23e9b520a9a9af7b97b'] = 'Type de transporteur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b04ad61ad875f6e7149fdd51c2e60ce2'] = 'Choix du type de transporteur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_803d8f90719db3a605cf4af72ab2d8ee'] = 'Type de transporteur par defaut';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_b41c57d638ef2d97b9231fb660dd136e'] = 'Configuration du paiement';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_417f4dcb050401b8e65f19f152bc2781'] = 'Detail du paiement';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_521e389890dc5f0b41a83fa187eb3878'] = 'Module de paiement';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_676b323eb96e2d3fa5b9afd415781b9a'] = 'Type de paiement';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_d8187ca1c7189a53c2ac6e8a7fe351d6'] = 'monsieur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_43ee1d83b74b6407b7bf4160a5b28fd7'] = 'madame';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_bf8fdb0995bc7db74f365551ffe9cf21'] = 'Monsieur';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_2b8713f4b603c6b9d9e8a10b6f4447d1'] = 'Madame';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_88183b946cc5f0e8c96b2e66e1c74a7e'] = 'Inconnu';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_d13270d4831bb2a2723f0fb5b573807c'] = 'Validation Fia-Net';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_e010021939a49b7cce07f0e546c1d54f'] = 'Voir le détail';
$_MODULE['<{fianetfraud}prestashop>fianetfraud_34f8a10ae57ac230a48fc44908bd40ad'] = 'Evaluation';
